#include <cassert>
#include <cmath>
#include <cstdio>
#include <cstdlib>
#include <cstring>

#define TASKNAME "lnp"

enum {OK, WA, PE, JE, NUM};
const char err [NUM] [4] = {"OK", "WA", "PE", "JE"};

FILE * fin, * fout, * fans;

void chkexit (const char * msg, int code)
{
 fprintf (stderr, "%s: %s\n", err[code], msg);
 exit (code);
}

void chkend (FILE * f, int mask)
{
 char ch;
 if (fscanf (f, " %c", &ch) == 1)
  chkexit ("Extra information given!", PE | mask);
}

const int MinN = 1, MaxN = 10, MaxC = 10, MaxP = (MaxN * (MaxN - 1)) >> 1,
 MaxL = (MaxP * (MaxP - 1)) >> 1;
typedef long long int64;
typedef int64 point [3];

point a [MaxN], p [MaxP], b [MaxL];
int x [MaxN], y [MaxN];
int n, k, l;

template <class T> T sqr (T x) {return x * x;}

bool construct (point & p, const point & a, const point & b)
{
 p[0] = a[1] * b[2] - a[2] * b[1];
 p[1] = a[2] * b[0] - a[0] * b[2];
 p[2] = a[0] * b[1] - a[1] * b[0];
 return sqr (p[0]) + sqr (p[1]) + sqr (p[2]);
}

bool is_finite_line (const point & p)
{
 return sqr (p[1]) + sqr (p[2]);
}

bool is_finite_point (const point & p)
{
 return sqr (p[0]);
}

bool incident (const point & a, const point & p)
{
 return !(a[0] * p[0] + a[1] * p[1] + a[2] * p[2]);
}

int answer (FILE * f, int mask)
{
 int i, cur, res;
 point r;
 int r0, r1, r2;

 if (fscanf (f, " %d", &res) != 1)
  chkexit ("No k given!", PE | mask);
 if (fscanf (f, " %d %d %d", &r1, &r2, &r0) != 3)
  chkexit ("Not enough numbers in input!", PE | mask);
 if (abs (r1) > 1000000000)
  chkexit ("a is too large!", WA | mask);
 if (abs (r2) > 1000000000)
  chkexit ("b is too large!", WA | mask);
 if (abs (r0) > 1000000000)
  chkexit ("c is too large!", WA | mask);
 if (r1 == 0 && r2 == 0)
  chkexit ("a or b should be non-zero!", WA | mask);
 chkend (f, mask);

 r[0] = r0;
 r[1] = r1;
 r[2] = r2;
 for (i = 0; i < n; i++)
  if (incident (a[i], r))
   break;
 if (i == n)
  chkexit ("No level 0 points are covered!", WA | mask);
 cur = 0;
 for (i = 0; i < l; i++)
  cur += incident (b[i], r);
 if (res != cur)
  chkexit ("Number of covered points does not match!", WA | mask);
 return res;
}

int main (int argc, char * argv [])
{
 int i, j;
 int rc, rj;
 assert (argc >= 4);
 if ((fin = fopen (argv[1], "r")) == NULL) chkexit ("No input file!", JE);
 if ((fout = fopen (argv[2], "r")) == NULL) chkexit ("No output file!", PE);
 if ((fans = fopen (argv[3], "r")) == NULL) chkexit ("No answer file!", JE);
 if (fscanf (fin, " %d", &n) != 1)
  chkexit ("No N in test!", JE);
 assert (n >= MinN && n <= MaxN);
 for (i = 0; i < n; i++)
 {
  if (fscanf (fin, " %d %d", &x[i], &y[i]) != 2)
   chkexit ("No x or y in test!", JE);
  assert (x[i] >= -MaxC && x[i] <= MaxC);
  assert (y[i] >= -MaxC && y[i] <= MaxC);
  a[i][0] = 1;
  a[i][1] = x[i];
  a[i][2] = y[i];
 }
 chkend (fin, JE);
 k = 0;
 for (i = 0; i < n - 1; i++)
  for (j = i + 1; j < n; j++)
   if (construct (p[k], a[i], a[j]) && is_finite_line (p[k]))
    k++;
 l = 0;
 for (i = 0; i < k - 1; i++)
  for (j = i + 1; j < k; j++)
   if (construct (b[l], p[i], p[j]) && is_finite_point (b[l]))
    l++;
 rc = answer (fout, OK);
 rj = answer (fans, JE);
 fclose (fin);
 fclose (fout);
 fclose (fans);
 if (rj > rc)
  chkexit ("Jury can cover more points!", WA);
 if (rj < rc)
  chkexit ("Contestant can cover more points!", JE);
 chkexit ("Contestant and jury cover the same number of points!", OK);
 return 0;
}
